@@ -40,3 +40,10 @@ medici[names(medici)=="Medici"] <- "Medici"
 # plot the marriage data, highlighting the Medici family
 #
 plot(nflo,vertex.col=1+get.vertex.attribute(nflo,"medici"))
+
+# plot the emon St. Helens network, with edge widths proportional
+# to 'Frequency', and edges labeled by their id
+data(emon)
+par(mar=c(0,0,0,0))
+plot(emon[[5]],edge.label=TRUE,edge.label.cex=0.6,
+     edge.col='gray',edge.lwd=(emon[[5]]%e%'Frequency')*2)
